@@ -13,7 +13,6 @@
 #    under the License.
 import re
 
-import six
 import yaql
 
 
@@ -33,9 +32,9 @@ class YaqlExpression(object):
 
     @staticmethod
     def match(expr):
-        if not isinstance(expr, six.string_types):
+        if not isinstance(expr, str):
             return False
-        if re.match('^[\s\w\d.:]*$', expr):
+        if re.match(r'^[\s\w\d.:]*$', expr):
             return False
         try:
             yaql.parse(expr)
