@@ -13,8 +13,8 @@
 import collections
 import json
 import tempfile
+from unittest import mock
 
-import mock
 
 from muranoclient.osc.v1 import environment as osc_env
 from muranoclient.tests.unit.osc.v1 import fakes
@@ -30,6 +30,26 @@ ENV_INFO = {'id': '1234',
             'tenant_id': 'xyz123',
             'version': '1'}
 
+ENV_MODEL = {
+    "defaultNetworks": {
+        "environment": {
+            "name": "env-network",
+            "?": {
+                "type": "io.murano.resources.NeutronNetwork",
+                "id": "5678"
+            }
+        },
+        "flat": None
+    },
+    "region": "RegionOne",
+    "name": "env",
+    "?": {
+        "updated": "2016-10-03 09:33:41.039789",
+        "type": "io.murano.Environment",
+        "id": "1234"
+    }
+}
+
 
 class TestEnvironment(fakes.TestApplicationCatalog):
     def setUp(self):
@@ -77,9 +97,9 @@ class TestListEnvironment(TestEnvironment):
         self.assertEqual(expected_data, data)
 
     @mock.patch('osc_lib.utils.get_item_properties')
-    def test_environment_list_with_options(self, mock_util):
+    def test_environment_list_with_all_tenants(self, mock_util):
         arglist = ['--all-tenants']
-        verifylist = [('all_tenants', True)]
+        verifylist = [('all_tenants', True), ('tenant', None)]
 
         mock_util.return_value = ('1234', 'Environment of all tenants',
                                   'fake deployed', '2015-12-16T17:31:54',
@@ -99,6 +119,32 @@ class TestListEnvironment(TestEnvironment):
                           'fake deployed', '2015-12-16T17:31:54',
                           '2015-12-16T17:31:54')]
         self.assertEqual(expected_data, data)
+        self.environment_mock.list.assert_called_once_with(True, None)
+
+    @mock.patch('osc_lib.utils.get_item_properties')
+    def test_environment_list_with_tenant(self, mock_util):
+        arglist = ['--tenant=ABC']
+        verifylist = [('all_tenants', False), ('tenant', 'ABC')]
+
+        mock_util.return_value = ('1234', 'Environment of tenant ABC',
+                                  'fake deployed', '2015-12-16T17:31:54',
+                                  '2015-12-16T17:31:54'
+                                  )
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Check that columns are correct
+        expected_columns = ['Id', 'Name', 'Status', 'Created', 'Updated']
+        self.assertEqual(expected_columns, columns)
+
+        # Check that data is correct
+        expected_data = [('1234', 'Environment of tenant ABC',
+                          'fake deployed', '2015-12-16T17:31:54',
+                          '2015-12-16T17:31:54')]
+        self.assertEqual(expected_data, data)
+        self.environment_mock.list.assert_called_once_with(False, 'ABC')
 
 
 class TestShowEnvironment(TestEnvironment):
@@ -440,7 +486,7 @@ class TestEnvironmentAppsEdit(TestEnvironment):
         # Command to test
         self.cmd = osc_env.EnvironmentAppsEdit(self.app, None)
 
-    def test_environment_deploy(self):
+    def test_environment_apps_edit(self):
         fake = collections.namedtuple('fakeEnv', 'services')
         self.environment_mock.get.side_effect = [
             fake(services=[
@@ -468,3 +514,71 @@ class TestEnvironmentAppsEdit(TestEnvironment):
             path='/',
             data=[{'?': {'name': 'dummy'}}]
         )
+
+
+class TestEnvironmentModelShow(TestEnvironment):
+    def setUp(self):
+        super(TestEnvironmentModelShow, self).setUp()
+        self.env_mock = \
+            self.app.client_manager.application_catalog.environments
+        self.env_mock.get_model.return_value = ENV_MODEL
+
+        # Command to test
+        self.cmd = osc_env.EnvironmentModelShow(self.app, None)
+
+    def test_environment_model_show_basic(self):
+        arglist = ['env-id']
+        verifylist = [('id', 'env-id')]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Check that columns are correct
+        expected_columns = ('?', 'defaultNetworks', 'name', 'region')
+        self.assertEqual(expected_columns, columns)
+
+        # Check that data is correct
+        self.assertItemsEqual(ENV_MODEL.values(), data)
+
+    def test_environment_model_show_full(self):
+        arglist = ['env-id', '--path', '/path', '--session-id', 'sess-id']
+        verifylist = [('id', 'env-id'), ('path', '/path'),
+                      ('session_id', 'sess-id')]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Check that columns are correct
+        expected_columns = ('?', 'defaultNetworks', 'name', 'region')
+        self.assertEqual(expected_columns, columns)
+
+        # Check that data is correct
+        self.assertItemsEqual(ENV_MODEL.values(), data)
+
+
+class TestEnvironmentModelEdit(TestEnvironment):
+    def setUp(self):
+        super(TestEnvironmentModelEdit, self).setUp()
+        self.env_mock = \
+            self.app.client_manager.application_catalog.environments
+        self.env_mock.update_model.return_value = ENV_MODEL
+
+        # Command to test
+        self.cmd = osc_env.EnvironmentModelEdit(self.app, None)
+
+    def test_environment_model_edit(self):
+        temp_file = tempfile.NamedTemporaryFile(prefix="murano-test", mode='w')
+        patch = [{'op': 'replace', 'path': '/name', 'value': 'dummy'}]
+        json.dump(patch, temp_file)
+        temp_file.file.flush()
+
+        arglist = ['env-id', temp_file.name, '--session-id', 'sess-id']
+        verifylist = [('id', 'env-id'), ('filename', temp_file.name),
+                      ('session_id', 'sess-id')]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Check that columns are correct
+        expected_columns = ('?', 'defaultNetworks', 'name', 'region')
+        self.assertEqual(expected_columns, columns)
+
+        # Check that data is correct
+        self.assertItemsEqual(ENV_MODEL.values(), data)
