@@ -12,15 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-import six
 import testtools
+from unittest import mock
 
 from muranoclient import client
 from muranoclient.v1 import actions
+from muranoclient.v1 import deployments
 import muranoclient.v1.environments as environments
 from muranoclient.v1 import packages
 import muranoclient.v1.sessions as sessions
+from muranoclient.v1 import static_actions
 import muranoclient.v1.templates as templates
 
 
@@ -202,16 +203,15 @@ class UnitTestsForClassesAndFunctions(testtools.TestCase):
         self.assertEqual('1234', result)
 
     def test_package_filter_pagination_next_marker(self):
-        """``PackageManager.filter`` handles `next_marker` parameter related
-        to pagination in API correctly.
-        """
+        # ``PackageManager.filter`` handles `next_marker` parameter related
+        # to pagination in API correctly.
         responses = [
             {'next_marker': 'test_marker',
              'packages': [{'name': 'test_package_1'}]},
             {'packages': [{'name': 'test_package_2'}]}
         ]
 
-        def json_request(method, url, *args, **kwargs):
+        def json_request(url, method, *args, **kwargs):
             self.assertIn('/v1/catalog/packages', url)
 
             return mock.MagicMock(), responses.pop(0)
@@ -231,7 +231,7 @@ class UnitTestsForClassesAndFunctions(testtools.TestCase):
             {'packages': [{'name': 'test_package_2'}]}
         ]
 
-        def json_request(method, url, *args, **kwargs):
+        def json_request(url, method, *args, **kwargs):
             self.assertIn('category=%D0%BF%D0%B8%D0%B2%D0%BE', url)
             return mock.MagicMock(), responses.pop(0)
 
@@ -239,7 +239,7 @@ class UnitTestsForClassesAndFunctions(testtools.TestCase):
         api.configure_mock(**{'json_request.side_effect': json_request})
 
         manager = packages.PackageManager(api)
-        category = six.b('\xd0\xbf\xd0\xb8\xd0\xb2\xd0\xbe')
+        category = b'\xd0\xbf\xd0\xb8\xd0\xb2\xd0\xbe'
         kwargs = {'category': category.decode('utf-8')}
         list(manager.filter(**kwargs))
 
@@ -252,9 +252,16 @@ class UnitTestsForClassesAndFunctions(testtools.TestCase):
         result = manager.get_result('testEnvId', '1234')
         self.assertEqual({'a': 'b'}, result)
 
+    def test_static_action_manager_call(self):
+        api_mock = mock.MagicMock(
+            json_request=lambda *args, **kwargs: (None, 'result'))
+        manager = static_actions.StaticActionManager(api_mock)
+        args = {'className': 'cls', 'methodName': 'method'}
+        result = manager.call(args).get_result()
+        self.assertEqual('result', result)
+
     def test_env_template_manager_list(self):
-        """It tests the list of environment templates.
-        """
+        """Tests the list of environment templates."""
         manager = templates.EnvTemplateManager(api)
         result = manager.list()
 
@@ -324,3 +331,24 @@ class UnitTestsForClassesAndFunctions(testtools.TestCase):
         result = manager.get('test')
 
         self.assertIsNotNone(result.manager)
+
+    def test_deployment_manager_list(self):
+        manager = deployments.DeploymentManager(api)
+        manager._list = mock.Mock(return_value=mock.sentinel.deployments)
+
+        result = manager.list(mock.sentinel.environment_id)
+        self.assertEqual(mock.sentinel.deployments, result)
+
+        manager._list.assert_called_once_with(
+            '/v1/environments/sentinel.environment_id/deployments',
+            'deployments')
+
+    def test_deployment_manager_list_all_environments(self):
+        manager = deployments.DeploymentManager(api)
+        manager._list = mock.Mock(return_value=mock.sentinel.deployments)
+
+        result = manager.list(mock.sentinel.environment_id,
+                              all_environments=True)
+        self.assertEqual(mock.sentinel.deployments, result)
+
+        manager._list.assert_called_once_with('/v1/deployments', 'deployments')
